# SPDX-FileCopyrightText: © Antonio López Rivera <antonlopezr99@gmail.com>
# SPDX-License-Identifier: GPL-3.0-only

"""
2D
--
"""

from mpl_plotter.two_d.plotters import line, scatter, heatmap, quiver, streamline, fill_area
from mpl_plotter.two_d.comparison import comparison
from mpl_plotter.two_d.panes import panes
